.. _spkg_python_flint:

python_flint: Bindings for FLINT and Arb
========================================

Description
-----------

Bindings for FLINT and Arb

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/python-flint/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`
- :ref:`spkg_flint`

Version Information
-------------------

package-version.txt::

    0.6.0

version_requirements.txt::

    python-flint

Equivalent System Packages
--------------------------

(none known)
